require 'test/unit'
require 'rgb2hex'

class Rgb2HexTest < Test::Unit::TestCase
	def test_defaults_to_black
		assert_equal "#000000",
			Rgb2Hex.convert
	end

	def test_converts_black
		assert_equal "#000000",
			Rgb2Hex.convert(0, 0, 0)
	end

	def test_converts_white
		assert_equal "#ffffff",
			Rgb2Hex.convert(255, 255, 255)
	end

	def test_converts_magenta
		assert_equal "#ff0090",
			Rgb2Hex.convert(255, 0, 144)
	end

	def test_converts_cyan
		assert_equal "#00ffff",
			Rgb2Hex.convert(0, 255, 255)
	end

	def test_throws_exeption_when_num_less_than_0
		exception = assert_raise(ArgumentError) do
			Rgb2Hex.convert(-1, 0, 0)
		end
		assert_equal "input argument is less than 0", exception.message
	end

	def test_throws_exeption_when_num_more_than_255
		exception = assert_raise(ArgumentError) do
			Rgb2Hex.convert(0, 0, 256)
		end
		assert_equal "input argument is more than 255", exception.message
	end

	def test_throws_exeption_when_multiple_nums_more_than_255
		exception = assert_raise(ArgumentError) do
			Rgb2Hex.convert(0, 1001, 256)
		end
		assert_equal "input argument is more than 255", exception.message
	end

	def test_throws_exeption_when_nums_are_less_than_0_and_more_than_255
		exception = assert_raise(ArgumentError) do
			Rgb2Hex.convert(362, 1001, -10)
		end
		assert_equal "input argument is less than 0", exception.message
	end

	def test_dirty_inputs
		assert_equal "#ff0090",
			Rgb2Hex.convert("255", "0", "144")

		assert_equal "#ff0090",
			Rgb2Hex.convert("255,", "0,", "144,")

		assert_equal "#ff0090",
			Rgb2Hex.convert("255,", "sadf0,", "- 144,")
	end

	def test_single_argument
		assert_equal "#ffffff",
			Rgb2Hex.convert("255, 255, 255")
	end

	def test_some_more_single_arguments
		assert_equal "#00ffff",
			Rgb2Hex.convert("rgb(0, 255, 255)")
		assert_equal "#00ffff",
			Rgb2Hex.convert("rgb[0; 255; 255]")
		assert_equal "#00ffff",
			Rgb2Hex.convert("rgb[0; 255; 255]")
		assert_equal "#00ffff",
			Rgb2Hex.convert("rgb[0; 255; 255]")
		assert_equal "#010203",
			Rgb2Hex.convert("red=1 green=2 blue=3")
	end

	def test_illegal_number_of_input_args
		assert_equal "illegal number of input arguments",
			Rgb2Hex.convert(1, 2)
	end
end